<?php
// This is a SPIP language file  --  Ceci est un fichier langue de SPIP
// extrait automatiquement de http://trad.spip.net/tradlang_module/paquet-sites?lang_cible=it
// ** ne pas modifier le fichier **

if (!defined('_ECRIRE_INC_VERSION')) {
	return;
}

$GLOBALS[$GLOBALS['idx_lang']] = array(

	// S
	'sites_description' => 'Siti e syndication in SPIP (privato e pubblica)',
	'sites_slogan' => 'Gestione dei siti e syndication in SPIP'
);

?>
